/*
 * Vifir - An electronic flight bag wannabe utility for aircraft pilots
 * Copyright (C) 2009 David Ludlow
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * dave@adsllc.com, PO Box 13070, Toledo, OH 43623
 */

#ifndef APPROACHSEARCHDIALOG_H_
#define APPROACHSEARCHDIALOG_H_

#include <gtkmm/dialog.h>
#include <gtkmm/entry.h>
#include <gtkmm/button.h>
#include <gtkmm/treeview.h>
#include <gtkmm/liststore.h>
#include <gtkmm/box.h>
#include <libglademm.h>
#include "ApproachPlate.h"
#include "DataStore.h"
#include "Config.h"
#include "OnScreenKeypad.h"

class ApproachSearchDialogModelColumns : public Gtk::TreeModelColumnRecord
{
public:
	ApproachSearchDialogModelColumns();

	Gtk::TreeModelColumn<std::string> PlateName;
	Gtk::TreeModelColumn<std::string> AirportIdent;
	Gtk::TreeModelColumn<std::string> AirportName;
	Gtk::TreeModelColumn<ApproachPlate*> PlateData;
};

class ApproachSearchDialog
{
public:
	ApproachSearchDialog(std::string *GladeFilename, DataStore *Data, Config *Cfg);
	virtual ~ApproachSearchDialog();

	int Run();
private:
	Glib::RefPtr<Gnome::Glade::Xml> refXml;
	Gtk::Dialog *GtkDialog;
	Gtk::Entry *AirportEntry;
	Gtk::TreeView *ApproachesTreeView;
	Gtk::Button *ViewButton;
	Gtk::Button *FrontMatterButton;
	Gtk::Button *CloseButton;
	Gtk::VBox *OnScreenKeypadParent;
	OnScreenKeypad *Keypad;

	ApproachSearchDialogModelColumns Columns;
	Glib::RefPtr<Gtk::ListStore> ListStore;

	void on_AirportEntry_changed();
	void on_ViewButton_clicked();
	void on_FrontMatterButton_clicked();
	void on_CloseButton_clicked();

	Config *Cfg;
	DataStore *Data;

	/* Something to store our matching items in */
	class MatchingItem
	{
	public:
		MatchingItem(Airport *AirP, ApproachPlate *Plate);
		std::string GetAirportIdent();
		std::string GetAirportName();
		std::string GetPlateName();
		ApproachPlate *GetApproachPlate();
		bool Matchi(std::string str);
	private:
		Airport *AirP;
		ApproachPlate *Plate;
	};
	std::vector<MatchingItem> MatchingItems;
};

#endif /*APPROACHSEARCHDIALOG_H_*/
